@@ -575,7 +575,7 @@ class AutoSuggestionServiceClient(metaclass=AutoSuggestionServiceClientMeta):
         # Done; return the response.
         return response
 
-    def __enter__(self):
+    def __enter__(self) -> "AutoSuggestionServiceClient":
         return self
 
     def __exit__(self, type, value, traceback):
