@@ -1052,7 +1052,7 @@ class QuestionServiceClient(metaclass=QuestionServiceClientMeta):
         # Done; return the response.
         return response
 
-    def __enter__(self):
+    def __enter__(self) -> "QuestionServiceClient":
         return self
 
     def __exit__(self, type, value, traceback):
